**Describe the bug**

I have an interface with a single method:

```java
public interface GreetingResourceInterface<T> {
    String hello(T pojo);
}
```
and a JAX-RS resource which implements it:

```java
@Path("/hello")
public class GreetingResource implements GreetingResourceInterface<MyPojo> {

    @Override
    @POST
    @Produces(MediaType.TEXT_PLAIN)
    @Consumes(MediaType.APPLICATION_JSON)
    public String hello(@Valid MyPojo pojo) {
        return "hello";
    }
}
```



**Expected behavior**

At startup with:

    mvn clean compile quarkus:dev
    
I got this Exception:

```java
14:02:18,137 ERROR [io.qua.dev.DevModeMain] Failed to start quarkus: java.lang.ExceptionInInitializerError
        at sun.reflect.NativeConstructorAccessorImpl.newInstance0(Native Method)
        at sun.reflect.NativeConstructorAccessorImpl.newInstance(NativeConstructorAccessorImpl.java:62)
        at sun.reflect.DelegatingConstructorAccessorImpl.newInstance(DelegatingConstructorAccessorImpl.java:45)
        at java.lang.reflect.Constructor.newInstance(Constructor.java:423)
        at java.lang.Class.newInstance(Class.java:442)
        at io.quarkus.runner.RuntimeRunner.run(RuntimeRunner.java:121)
        at io.quarkus.dev.DevModeMain.doStart(DevModeMain.java:159)
        at io.quarkus.dev.DevModeMain.main(DevModeMain.java:93)
Caused by: java.lang.RuntimeException: Failed to start quarkus
        at io.quarkus.runner.ApplicationImpl1.<clinit>(Unknown Source)
        ... 8 more
Caused by: java.lang.ArrayIndexOutOfBoundsException: 1
        at org.hibernate.validator.internal.properties.javabean.JavaBeanExecutable.getParameters(JavaBeanExecutable.java:213)
        at org.hibernate.validator.internal.properties.javabean.JavaBeanExecutable.<init>(JavaBeanExecutable.java:45)
        at org.hibernate.validator.internal.properties.javabean.JavaBeanConstructor.<init>(JavaBeanConstructor.java:20)
        at org.hibernate.validator.internal.properties.javabean.JavaBeanHelper.executable(JavaBeanHelper.java:109)
        at org.hibernate.validator.internal.properties.javabean.JavaBeanHelper.executable(JavaBeanHelper.java:104)
        at org.hibernate.validator.internal.metadata.provider.AnnotationMetaDataProvider.findExecutableMetaData(AnnotationMetaDataProvider.java:307)
        at org.hibernate.validator.internal.metadata.provider.AnnotationMetaDataProvider.getMetaData(AnnotationMetaDataProvider.java:292)
        at org.hibernate.validator.internal.metadata.provider.AnnotationMetaDataProvider.getConstructorMetaData(AnnotationMetaDataProvider.java:273)
        at org.hibernate.validator.internal.metadata.provider.AnnotationMetaDataProvider.retrieveBeanConfiguration(AnnotationMetaDataProvider.java:131)
        at org.hibernate.validator.internal.metadata.provider.AnnotationMetaDataProvider.getBeanConfiguration(AnnotationMetaDataProvider.java:120)
        at org.hibernate.validator.internal.metadata.PredefinedScopeBeanMetaDataManager.getBeanConfigurationForHierarchy(PredefinedScopeBeanMetaDataManager.java:165)
        at org.hibernate.validator.internal.metadata.PredefinedScopeBeanMetaDataManager.createBeanMetaData(PredefinedScopeBeanMetaDataManager.java:132)
        at org.hibernate.validator.internal.metadata.PredefinedScopeBeanMetaDataManager.<init>(PredefinedScopeBeanMetaDataManager.java:83)
        at org.hibernate.validator.internal.engine.PredefinedScopeValidatorFactoryImpl.<init>(PredefinedScopeValidatorFactoryImpl.java:175)
        at org.hibernate.validator.PredefinedScopeHibernateValidator.buildValidatorFactory(PredefinedScopeHibernateValidator.java:42)
        at org.hibernate.validator.internal.engine.AbstractConfigurationImpl.buildValidatorFactory(AbstractConfigurationImpl.java:369)
        at io.quarkus.hibernate.validator.runtime.HibernateValidatorTemplate.initializeValidatorFactory(HibernateValidatorTemplate.java:56)
        at io.quarkus.deployment.steps.HibernateValidatorProcessor$build6.deploy(Unknown Source)
        ... 9 more
```



**Actual behavior**

When the executable of the:
 
    org.hibernate.validator.internal.properties.javabean.JavaBeanExecutable.getParameters(java.lang.reflect.Executable) 
    
method is:
 
    io.smallrye.config.ConfigSourceMap$EntrySet$Itr(io.smallrye.config.ConfigSourceMap$EntrySet,java.util.Iterator)
    
it does a bad calculation of "explicitlyDeclaredParameterIndex", accessing to the genericParameterTypes array with index[1] raise the
Exception.

**To Reproduce**

Steps to reproduce the behavior:
1. Unzip the attached test-case
2. mvn clean compile quarkus:dev

**Configuration**

None


**Environment (please complete the following information):**
 - Output of `uname -a` or `ver`:
  
    Darwin WMICTLM1P.local 18.6.0 Darwin Kernel Version 18.6.0: Thu Apr 25 23:16:27 PDT 2019; root:xnu-4903.261.4~2/RELEASE_X86_64 x86_64
 - Output of `java -version`:
  
    java version "1.8.0_152"
 - Quarkus version or git rev: 
    
    0.15.0 

**Additional context**
The same exact problem can be replicated from the attached test-case.

There is another issue with javax.validation and Interface, but in own opinion is not related:

https://github.com/quarkusio/quarkus/issues/1888

